#
# spec file for package python-opentelemetry-exporter-otlp-proto-common
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-opentelemetry-exporter-otlp-proto-common
Version:        1.29.0
Release:        1.1
Summary:        OpenTelemetry Protobuf encoding
License:        Apache-2.0
URL:            https://github.com/open-telemetry/opentelemetry-python
Source:         https://files.pythonhosted.org/packages/source/o/opentelemetry-exporter-otlp-proto-common/opentelemetry_exporter_otlp_proto_common-%{version}.tar.gz
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module opentelemetry-proto = %{version}}
BuildRequires:  %{python_module opentelemetry-sdk = %{version}}
BuildRequires:  %{python_module opentelemetry-test-utils}
BuildRequires:  %{python_module pytest}
# /SECTION
BuildRequires:  fdupes
Requires:       python-opentelemetry-proto = %{version}
BuildArch:      noarch
%python_subpackages

%description
This library is provided as a convenience to encode to Protobuf. Currently used by:

* opentelemetry-exporter-otlp-proto-grpc
* opentelemetry-exporter-otlp-proto-http

%prep
%autosetup -p1 -n opentelemetry_exporter_otlp_proto_common-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%dir %{python_sitelib}/opentelemetry
%dir %{python_sitelib}/opentelemetry/exporter
%dir %{python_sitelib}/opentelemetry/exporter/otlp
%dir %{python_sitelib}/opentelemetry/exporter/otlp/proto
%{python_sitelib}/opentelemetry/exporter/otlp/proto/common
%{python_sitelib}/opentelemetry_exporter_otlp_proto_common-%{version}.dist-info

%changelog
* Wed Jan  8 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.29.0
  * Fix crash exporting a log record with None body
  * Fix metrics export with exemplar and no context and filtering observable instruments
  * Fix recursion error with sdk disabled and handler added to root logger
  * sdk: setup EventLogger when OTEL_PYTHON_LOGGING_AUTO_INSTRUMENTATION_ENABLED is set
  * api: fix logging of duplicate EventLogger setup warning
  * sdk: fix setting of process owner in ProcessResourceDetector
  * sdk: fix serialization of logs severity_number field to int
  * Remove `TestBase.assertEqualSpanInstrumentationInfo` method,
    use `assertEqualSpanInstrumentationScope` instead
  * sdk: instantiate lazily `ExemplarBucket`s in `ExemplarReservoir`s
  * semantic-conventions: Bump to 1.29.0
- from version 1.28.0
  * Removed superfluous py.typed markers and added them where they were missing
  * Include metric info in encoding exceptions
  * sdk: Add support for log formatting
  * sdk: Add Host resource detector
  * sdk: Implementation of exemplars
  * Implement events sdk
  * Update semantic conventions to version 1.28.0
  * Add support to protobuf 5+ and drop support to protobuf 3 and 4
  * Update environment variable descriptions to match signal
  * Record logger name as the instrumentation scope name
  * Fix memory leak in exporter and reader
  * Drop `OTEL_PYTHON_EXPERIMENTAL_DISABLE_PROMETHEUS_UNIT_NORMALIZATION` environment variable
  * Improve compatibility with other logging libraries that override
    `LogRecord.getMessage()` in order to customize message formatting
* Wed Sep  4 2024 Guang Yee <gyee@suse.com>
- update to 1.27.0:
  * Implementation of Events API
  * Make log sdk add exception.message to logRecord for exceptions whose argument is an exception not a string message
  * Fix use of link.attributes.dropped, which may not exist
  * Running mypy on SDK resources
  * Added py.typed file to top-level module
  * Drop Final annotation from Enum in semantic conventions
  * Update log export example to not use root logger
  * Update semantic conventions to version 1.27.0
  * Add support to type bytes for OTLP AnyValue
  * Export ExponentialHistogram and ExponentialHistogramDataPoint
  * Implement Client Key and Certificate File Support for All OTLP Exporters
  * Remove _start_time_unix_nano attribute from _ViewInstrumentMatch in favor of using time_ns() at the moment when the aggregation object is created
* Mon Jun 17 2024 Dirk Müller <dmueller@suse.com>
- update to 1.25.0:
  * Fix class BoundedAttributes to have RLock rather than Lock
  * Remove thread lock by loading RuntimeContext explicitly.
  * Update proto version to v1.2.0
  * Add to_json method to ExponentialHistogram
  * Bump mypy to 1.9.0
  * Fix exponential histograms
  * Fix otlp exporter to export log_record.observed_timestamp
  * Add capture the fully qualified type name for raised
    exceptions in spans
  * Prometheus exporter sort label keys to prevent duplicate
    metrics when user input changes order
  * Rename test objects to avoid pytest warnings
  * Add span flags to OTLP spans and links
  * Record links with invalid SpanContext if either attributes or
    TraceState are not empty
  * Add OpenTelemetry trove classifiers to PyPI packages ([#3913]
  * Fix prometheus metric name and unit conversion (#3924)
  * Add parameters for Distros and configurators to configure
    autoinstrumentation in addition to existing environment
    variables.
* Fri May  3 2024 Dirk Müller <dmueller@suse.com>
- use modern python on sle15
* Wed Apr  3 2024 Dirk Müller <dmueller@suse.com>
- update to 1.24.0:
  * Make create_gauge non-abstract method
  * Make `tracer.start_as_current_span()` decorator work with
    async functions
  * Fix python 3.12 deprecation warning
  * bump mypy to 0.982
  * Add support for OTEL_SDK_DISABLED environment variable
  * Fix ValueError message for PeriodicExportingMetricsReader
  * Use `BaseException` instead of `Exception` in
    `record_exception`
  * Make span.record_exception more robust
  * Fix license field in pyproject.toml files
* Sat Mar 23 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update version of dependencies
* Fri Mar 15 2024 Dirk Müller <dmueller@suse.com>
- update to 1.23.0:
  * Use Attribute rather than boundattribute in logrecord
  * Fix flush error when no LoggerProvider configured for
    LoggingHandler
  * Fix `OTLPMetricExporter` ignores `preferred_aggregation`
    property
  * Logs: set `observed_timestamp` field
  * Add missing Resource SchemaURL in OTLP exporters
  * Fix loglevel warning text
  * Prometheus Exporter string representation for target_info
    labels
  * Logs: ObservedTimestamp field is missing in console exporter
    output
  * Fix explicit bucket histogram aggregation
  * Add `code.lineno`, `code.function` and `code.filepath` to all
    logs
  * Add Synchronous Gauge instrument
  * Drop support for 3.7
  * Include key in attribute sequence warning
  * Upgrade markupsafe, Flask and related dependencies to dev and
    test environments
  * Handle HTTP 2XX responses as successful in OTLP exporters
  * Improve Resource Detector timeout messaging
  * Add Proxy classes for logging
  * Remove dependency on 'backoff' library
* Mon Jan 15 2024 Dirk Müller <dmueller@suse.com>
- Initial package (1.22.0)
